@@ -475,7 +475,7 @@ class VeeamEm:
         roles_uid: List[str],
         flr_settings=None,
         sql_settings=None,
-        h_scope_objects=None,
+        h_scope_objects: Optional[List[Tuple[str, str]]] = None,
         restore_all_vms: bool = False,
         content_type: str = 'json',
     ):
@@ -501,7 +501,9 @@ class VeeamEm:
          To get a list of IDs for available roles,
          call :py:func:`get_roles`.
         :param h_scope_objects: Restore scope assigned to the
-         added account.
+         added account see :py:func:`get_hierarchy_obj_ref_type`
+         to generate each item in list. List of tuples i.e.
+         `[(hierarchy_object_ref, object_name)]`.
         :param flr_settings: File-level restore restrictions
          assigned to the added account. see
          :py:func:`get_account_flr_settings_spec`
@@ -525,14 +527,20 @@ class VeeamEm:
                 AllowRestoreAllVms=restore_all_vms,
                 AccountName=name,
                 AccountType=a_type,
-                Roles=list(map(self.get_account_role_spec, roles_uid)),
+                Roles=dict(
+                    EnterpriseRoles=[
+                        dict(EnterpriseRoleUid=i) for i in roles_uid
+                    ]
+                ),
             )
             if flr_settings:
                 payload['FlrSettings'] = flr_settings
             if sql_settings:
                 payload['SqlSettings'] = sql_settings
             if h_scope_objects:
-                payload['HierarchyScopeObjects'] = h_scope_objects
+                payload[
+                    'HierarchyScopeObjects'
+                ] = self.get_hierarchy_scope_objects(h_scope_objects)
             # create payload
             kwargs.update(dict(payload=payload))
         else:
@@ -629,14 +637,10 @@ class VeeamEm:
          infrastructure hierarchy.
         :return:
         """
-        return dict(
-            HierarchyScopeItem=dict(
-                HierarchyObjRef=h_object_ref, ObjectName=object_name
-            )
-        )
+        return dict(HierarchyObjRef=h_object_ref, ObjectName=object_name)
 
     @staticmethod
-    def get_hierarchy_scope_objects(objects: List[Tuple]) -> List[Dict]:
+    def get_hierarchy_scope_objects(objects: List[Tuple]) -> Dict:
         """Get Hierarchy scope objects.
 
         :param objects: list of tuples. first item is ``HierarchyObjRef``:
@@ -646,11 +650,11 @@ class VeeamEm:
         infrastructure hierarchy.
         :return: list of dictionaries
         """
-        result = []
+        result = list()
         for obj in objects:
             item = VeeamEm.get_hierarchy_scope_object(obj[0], obj[1])
             result.append(item)
-        return result
+        return dict(HierarchyScopeItems=result)
 
     @staticmethod
     def get_account_sql_settings_spec(deny_in_place_restore: bool) -> Dict:
@@ -689,7 +693,7 @@ class VeeamEm:
     @staticmethod
     def get_account_role_spec(uid):
         """Get account role specification."""
-        return dict(EnterpriseRole=[dict(EnterpriseRoleUid=uid)])
+        return dict(EnterpriseRoles=[dict(EnterpriseRoleUid=uid)])
 
     def get_accounts(self) -> List[Dict]:
         """Get available accounts.
@@ -868,58 +872,25 @@ class VeeamEm:
         )
         return data
 
-    def add_scope_to_account(
-        self,
-        account_uuid: str,
-        h_object_ref: str,
-        object_name: str,
-        content_type: str = 'json',
+    def add_scopes_to_account(
+        self, account_uuid: str, h_objects_ref: List[Tuple]
     ):
-        """Add Scope to Account.
+        """Add scopes to account.
 
         Assigns a restore scope to the account having the
         specified ID. The account is added to Veeam Backup
         Enterprise Manager and has a specific security role.
 
         :param account_uuid: account identifier
-        :param h_object_ref: Reference to the object in the
-         virtual infrastructure hierarchy.
-        :param object_name: Name of the object in the virtual
-         infrastructure hierarchy.
-        :param content_type: whether to use xml or json api representation
+        :param h_objects_ref: Reference list to the objects (ref,name)
         :return:
         """
-        kwargs = dict(
-            url=f'/security/accounts/{account_uuid}/scopes', method=self.POST,
+        payload = self.get_hierarchy_scope_objects(h_objects_ref)
+        data = self.request(
+            f'/security/accounts/{account_uuid}/scopes',
+            method=self.POST,
+            payload=payload,
         )
-        if content_type == 'json':
-            payload = self.get_hierarchy_scope_object(
-                h_object_ref, object_name
-            )
-            # create payload
-            kwargs.update(dict(payload=payload))
-        else:
-            xml_doc = ElementTree.Element(
-                "HierarchyScopeCreateSpec", attrib={'xmlns': self.xmlns}
-            )
-            h_scope_object_node = ElementTree.SubElement(
-                xml_doc, 'HierarchyScopeItem'
-            )
-            h_object_ref_node = ElementTree.SubElement(
-                h_scope_object_node, 'HierarchyObjRef'
-            )
-            h_object_ref_node.text = h_object_ref
-            h_object_name_node = ElementTree.SubElement(
-                h_scope_object_node, 'ObjectName'
-            )
-            h_object_name_node.text = object_name
-            # creating payload aka data
-            _kwargs = {
-                'data': ElementTree.tostring(xml_doc),
-                'headers': {'Content-Type': 'application/xml'},
-            }
-            kwargs.update(_kwargs)
-        data = self.request(**kwargs)
         return data
 
     def remove_scope_from_account(
